@@ -5,6 +5,7 @@
 #' @docType package
 #' @name edeaR
 #'
+## usethis namespace: start
 #' @importFrom data.table data.table
 #' @importFrom data.table :=
 #' @importFrom data.table as.data.table
@@ -23,6 +24,14 @@
 #' @importFrom lubridate ymd_hms
 #' @importFrom lubridate wday
 #' @importFrom lubridate interval
+#' @importFrom lubridate year
+#' @importFrom lubridate hour
+#' @importFrom lubridate minute
+#' @importFrom lubridate second
+#' @importFrom lubridate hours
+#' @importFrom lubridate minutes
+#' @importFrom lubridate seconds
+#' @importFrom lubridate make_date
 #' @importFrom glue glue
 #' @importFrom stats median
 #' @importFrom stats na.omit
@@ -37,7 +46,11 @@
 #' @importFrom utils data
 #' @import stringr
 #' @importFrom rlang expr_text
+#' @importFrom lifecycle deprecated
+#' @importFrom rlang maybe_missing
+## usethis namespace: end
 
 
-globalVariables(c(".", ".order","min_order"))
+globalVariables(c(".", ".order","min_order", "n"))
+"_PACKAGE"
 NULL
