@@ -1,41 +1,52 @@
-#' Filter: Processing Time
+#' @title Filter Processing Time
 #'
-#' Filters cases based on their processing time.
+#' @description Filters cases based on their \code{\link{processing_time}}.
 #'
-#'
-#' This filter can be used by using an interval or by using a percentage.
+#' This filter can be used by using an \code{interval} or by using a \code{percentage}.
 #' The percentage will always start with the shortest cases first and stop
 #' including cases when the specified percentile is reached. On the other hand, an absolute
 #' interval can be defined instead to filter cases which have a processing time in this interval. The time units
-#' in which this interval is defined can be submitted with the units argument.
+#' in which this interval is defined can be supplied with the \code{units} argument.
 #'
-#' @param interval An duration interval (numeric vector of length 2) to be used for absolute. Half open interval can be created using NA.
-#' @param percentage A percentage p to be used for relative filtering.
-#' @param units The time unit used for defining filter intervals.
+#' @param interval,percentage Provide either \code{interval} or \code{percentage}.\cr
+#' \code{interval} (\code{\link{numeric}} vector of length 2): A duration interval. Half open interval can be created using \code{\link{NA}}.\cr
+#' \code{percentage} (\code{\link{numeric}}): A percentage p to be used for relative filtering.
 #'
 #' @inherit filter_activity params references seealso return
+#' @inherit processing_time params
+#'
+#' @seealso \code{\link{processing_time}}
+#'
+#' @family filters
 #'
 #' @export filter_processing_time
-
-filter_processing_time <- function(eventlog, interval, percentage, reverse, units, ...) {
-	UseMethod("filter_processing_time")
-}
-
-#' @describeIn filter_processing_time Filter event log
-#' @export
-
-filter_processing_time.eventlog <- function(eventlog,
+filter_processing_time <- function(log,
 								   interval = NULL,
 								   percentage = NULL,
 								   reverse = FALSE,
-								   units = c("days","hours","mins","secs","weeks"),
-								   ...) {
+								   units = c("auto", "secs", "mins", "hours", "days", "weeks"),
+								   eventlog = deprecated()) {
+	UseMethod("filter_processing_time")
+}
 
-	units <- match.arg(units)
+#' @describeIn filter_processing_time Filters cases for a \code{\link[bupaR]{log}}.
+#' @export
+filter_processing_time.log <- function(log,
+									   interval = NULL,
+									   percentage = NULL,
+									   reverse = FALSE,
+									   units = c("auto", "secs", "mins", "hours", "days", "weeks"),
+									   eventlog = deprecated()) {
 
-	percentage  <- deprecated_perc(percentage, ...)
-	interval[1] <- deprecated_lower_thr(interval[1], ...)
-	interval[2] <- deprecated_upper_thr(interval[2], ...)
+	if(lifecycle::is_present(eventlog)) {
+		lifecycle::deprecate_warn(
+			when = "0.9.0",
+			what = "filter_processing_time(eventlog)",
+			with = "filter_processing_time(log)")
+		log <- eventlog
+	}
+
+	units <- rlang::arg_match(units)
 
 	if(!is.null(interval) && (length(interval) != 2 || !is.numeric(interval) || any(interval < 0, na.rm = T) || all(is.na(interval)) )) {
 		stop("Interval should be a positive numeric vector of length 2. One of the elements can be NA to create open intervals.")
@@ -49,36 +60,45 @@ filter_processing_time.eventlog <- function(eventlog,
 	else if((!is.null(interval)) & !is.null(percentage))
 		stop("Cannot filter on both interval and percentage simultaneously.")
 	else if(!is.null(percentage))
-		filter_processing_time_percentile(eventlog,
-												 percentage = percentage,
-												 reverse = reverse)
+		filter_processing_time_percentile(log,
+										  percentage = percentage,
+										  reverse = reverse)
 	else
-		filter_processing_time_threshold(eventlog,
-												lower_threshold = interval[1],
-												upper_threshold = interval[2],
-												reverse = reverse,
-												units = units)
+		filter_processing_time_threshold(log,
+										 lower_threshold = interval[1],
+										 upper_threshold = interval[2],
+										 reverse = reverse,
+										 units = units)
 }
 
-#' @describeIn filter_processing_time Filter grouped event log
+#' @describeIn filter_processing_time Filters cases for a \code{\link[bupaR]{grouped_log}}.
 #' @export
+filter_processing_time.grouped_log <- function(log,
+											   interval = NULL,
+											   percentage = NULL,
+											   reverse = FALSE,
+											   units = c("auto", "secs", "mins", "hours", "days", "weeks"),
+											   eventlog = deprecated()) {
 
+	if(lifecycle::is_present(eventlog)) {
+		lifecycle::deprecate_warn(
+			when = "0.9.0",
+			what = "filter_processing_time(eventlog)",
+			with = "filter_processing_time(log)")
+		log <- eventlog
+	}
 
-filter_processing_time.grouped_eventlog <- function(eventlog,
-											interval = NULL,
-											percentage = NULL,
-											reverse = FALSE,
-											units = c("days","hours","mins","secs","weeks"),
-											...) {
-	grouped_filter(eventlog, filter_processing_time, interval = interval, percentage = percentage, reverse, units, ...)
+	bupaR:::apply_grouped_fun(log, fun = filter_processing_time.log, interval, percentage, reverse, units, .ignore_groups = FALSE, .keep_groups = TRUE, .returns_log = TRUE)
+	#grouped_filter(eventlog, filter_processing_time, interval = interval, percentage = percentage, reverse, units, ...)
 }
 
-
 #' @rdname filter_processing_time
+#' @keywords internal
 #' @export ifilter_processing_time
-
 ifilter_processing_time <- function(eventlog) {
 
+	lifecycle::deprecate_warn("0.9.0", "ifilter_processing_time()")
+
 	ui <- miniPage(
 		gadgetTitleBar("Filter Processing Time"),
 		miniContentPanel(
