@@ -14,7 +14,7 @@ plot_idle_time <- function(x, ...) {
 			scale_y_continuous() +
 			theme_light() +
 			coord_flip() +
-			labs(x = "", y = "Idle time per case (in {units})") -> p
+			labs(x = "", y = glue("Idle time per case (in {units})")) -> p
 	}
 	else if(level == "case") {
 		x %>%
@@ -24,7 +24,7 @@ plot_idle_time <- function(x, ...) {
 			theme_light() +
 			scale_y_continuous() +
 			theme(axis.text.x = element_blank(), axis.ticks.x = element_blank()) +
-			labs(x = "Cases", y = "Idle time (in {units})") -> p
+			labs(x = "Cases", y = glue("Idle time (in {units})")) -> p
 	}
 	else if(level == "trace") {
 		stop("No plot availabe at this level")
@@ -32,17 +32,17 @@ plot_idle_time <- function(x, ...) {
 	else if(level == "resource") {
 		x %>%
 			ggplot(aes_string(glue("reorder({mapping$resource_id}, idle_time)"), "idle_time")) +
-			geom_col(aes(fill = idle_time)) +
+			geom_col(aes(fill = as.numeric(idle_time))) +
 			scale_fill_continuous_tableau(name = glue("Idle time (in {units})"), palette = "Blue") +
 			scale_y_continuous() +
 			coord_flip() +
 			theme_light() +
-			labs(x = "Resources",y = "Idle time (in {units})") -> p
+			labs(x = "Resources",y = glue("Idle time (in {units})")) -> p
 	}
 
 
-	if(!is.null(attr(x, "groups"))) {
-		p <-	p + facet_grid(as.formula(paste(c(paste(attr(x, "groups"), collapse = "+"), "~." ), collapse = "")), scales = "free_y")
+	if(!is.null(mapping$groups)) {
+		p <-	p + facet_grid(as.formula(paste(c(paste(mapping$groups, collapse = "+"), "~." ), collapse = "")), scales = "free_y")
 	}
 
 	return(p)
