@@ -11,18 +11,32 @@
 #'
 #' @export size_of_repetitions
 #'
-size_of_repetitions <- function(eventlog, type, level, append, ...) {
+size_of_repetitions <- function(log,
+								type = c("all","repeat","redo"),
+								level = c("log","case","activity","resource","resource-activity"),
+								append = deprecated(),
+								append_column = NULL,
+								eventlog = deprecated()) {
 	UseMethod("size_of_repetitions")
 }
 #' @describeIn size_of_repetitions Size of repetitions for eventlog
 #' @export
 
-size_of_repetitions.eventlog <- function(eventlog,
+size_of_repetitions.eventlog <- function(log,
 								type = c("all","repeat","redo"),
 								level = c("log","case","activity","resource","resource-activity"),
-								append = FALSE,
+								append = deprecated(),
 								append_column = NULL,
-								...){
+								eventlog = deprecated()){
+
+	if(lifecycle::is_present(eventlog)) {
+		lifecycle::deprecate_warn(
+			when = "0.9.0",
+			what = "size_of_repetitions(eventlog)",
+			with = "size_of_repetitions(log)")
+		log <- eventlog
+	}
+	append <- lifecycle_warning_append(append)
 
 	if(all((type) == c("all", "repeat","redo")))
 		message("Using default type: all")
@@ -31,7 +45,6 @@ size_of_repetitions.eventlog <- function(eventlog,
 
 	type <- match.arg(type)
 	level <- match.arg(level)
-	level <- deprecated_level(level, ...)
 
 	if(is.null(append_column)) {
 		append_column <- case_when(level == "case" ~ "median",
@@ -70,10 +83,10 @@ size_of_repetitions.eventlog <- function(eventlog,
 
 	}
 
-	output <- FUN(eventlog = eventlog)
+	output <- FUN(eventlog = log)
 
 
-	output <- return_metric(eventlog, output, level, append, append_column, "size_of_repetitions", 10)
+	output <- return_metric(log, output, level, append, append_column, "size_of_repetitions", 10)
 	attr(output, "type") <- type
 	return(output)
 }
@@ -81,16 +94,23 @@ size_of_repetitions.eventlog <- function(eventlog,
 #' @describeIn size_of_repetitions Size of repetitions for grouped event log
 #' @export
 
-size_of_repetitions.grouped_eventlog <- function(eventlog,
+size_of_repetitions.grouped_eventlog <- function(log,
 												 type = c("repeat","redo"),
 												 level = c("log","case","activity","resource","resource-activity"),
-												 append = FALSE,
+												 append = deprecated(),
 												 append_column = NULL,
-												 ...){
+												 eventlog = deprecated()){
+	if(lifecycle::is_present(eventlog)) {
+		lifecycle::deprecate_warn(
+			when = "0.9.0",
+			what = "size_of_repetitions(eventlog)",
+			with = "size_of_repetitions(log)")
+		log <- eventlog
+	}
+	append <- lifecycle_warning_append(append)
 
 	type <- match.arg(type)
 	level <- match.arg(level)
-	level <- deprecated_level(level, ...)
 
 	if(is.null(append_column)) {
 		append_column <- case_when(level == "case" ~ "median",
@@ -120,15 +140,56 @@ size_of_repetitions.grouped_eventlog <- function(eventlog,
 
 	}
 
-	if(level != "log") {
-		output <- grouped_metric(eventlog, FUN)
-	}
-	else {
-		output <- grouped_metric_raw_log(eventlog, FUN)
-	}
+	output <- bupaR:::apply_grouped_fun(log, FUN, .ignore_groups = FALSE, .keep_groups = FALSE, .returns_log = FALSE)
 
-
-	output <- return_metric(eventlog, output, level, append, append_column, "size_of_repetitions", 10)
+	output <- return_metric(log, output, level, append, append_column, "size_of_repetitions", 10)
 	attr(output, "type") <- type
 	return(output)
 }
+
+#' @describeIn size_of_repetitions Size of repetitions for activitylog
+#' @export
+
+size_of_repetitions.activitylog <- function(log,
+												 type = c("repeat","redo"),
+												 level = c("log","case","activity","resource","resource-activity"),
+												 append = deprecated(),
+												 append_column = NULL,
+												 eventlog = deprecated()){
+	if(lifecycle::is_present(eventlog)) {
+		lifecycle::deprecate_warn(
+			when = "0.9.0",
+			what = "size_of_selfloops(eventlog)",
+			with = "size_of_selfloops(log)")
+		log <- eventlog
+	}
+	append <- lifecycle_warning_append(append)
+
+	log %>% to_eventlog %>% size_of_repetitions(type, level, append, append_column)
+}
+
+#' @describeIn size_of_repetitions Size of repetitions for grouped activitylog
+#' @export
+
+size_of_repetitions.grouped_activitylog <- function(log,
+												 type = c("repeat","redo"),
+												 level = c("log","case","activity","resource","resource-activity"),
+												 append = deprecated(),
+												 append_column = NULL,
+												 eventlog = deprecated()){
+
+	if(lifecycle::is_present(eventlog)) {
+		lifecycle::deprecate_warn(
+			when = "0.9.0",
+			what = "size_of_selfloops(eventlog)",
+			with = "size_of_selfloops(log)")
+		log <- eventlog
+	}
+	append <- lifecycle_warning_append(append)
+
+	size_of_repetitions.grouped_eventlog(bupaR::to_eventlog(log),
+									   type = type,
+									   level = level,
+									   append = append,
+									   append_column = append_column)
+}
