@@ -2,14 +2,15 @@
 
 
 throughput_time_log <- function(eventlog,
-								 units) {
+								units,
+								work_schedule) {
 
-	throughput_time_case(eventlog, units = units) -> raw
+	throughput_time_case(eventlog, units = units, work_schedule = work_schedule) -> raw
 
 
 	raw %>%
 		pull(throughput_time) %>%
-		as.double(units = units) %>%
+		#as.double(units = units) %>%
 		summary_statistics() -> output
 
 
