@@ -1,9 +1,9 @@
 
-trace_coverage_log <- function(eventlog,
-						   threshold = NULL) {
+trace_coverage_log <- function(log) {
+
 	relative <- NULL
 
-	trace_coverage_trace(eventlog) -> raw
+	trace_coverage_trace(log) -> raw
 	raw %>%
 		pull(relative) %>%
 		summary_statistics() -> output
